;; Generated package description from xref.el  -*- no-byte-compile: t -*-
(define-package "xref" "1.7.0.0.20251018.61546" "Cross-referencing commands" '((emacs "26.1")) :commit "48357dc612ffe2d6b286e3f99a0e7e9c80cfcbb8" :url "https://elpa.gnu.org/packages/xref.html")
